#include <bits/stdc++.h>

#define endl '\n'
#define range(i, a, b) for(int i = a; i < b; ++i)

struct barrier
{
    int idx, height, max_increase;

    bool operator<(const barrier& other) {
        return this->idx < other.idx;
    }
};

int calculate_water(const std::vector<barrier>& b)
{
    auto sum = 0;

    for(auto it = b.begin(); it != std::prev(b.end()); ) {
        auto n = std::next(it);
        while(n->height == -1) {
            n = std::next(n);
        }

        auto delta = n->idx - it->idx;

        auto min_height = std::min(it->height, n->height) * delta;
        sum += min_height;

        it = n;
    }

    return sum;
}

int main()
{
    std::ios::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int n;
    std::cin >> n;

    std::vector<barrier> heights(n);

    int h;
    range(i, 0, n) {
        std::cin >> h;
        heights[i] = {i, h, -1};
    }

    int k;
    std::cin >> k;

    int idx;
    range(i, 0, k) {
        std::cin >> idx >> h;
        heights[idx].max_increase = h;
    }

    // Look for inner barriers and remove them
    auto last_idx = 0;
    auto last_height = heights[last_idx].height;

    for(auto it = std::next(heights.begin()); it != heights.end(); ++it) {
        auto curr_idx = std::distance(heights.begin(), it);

        if(it->height == last_height) { // If we reached the last max height
            auto dist = curr_idx - last_idx;
            if(dist > 1) { // If we went past some shorter barriers
                range(i, last_idx + 1, curr_idx) {
                    heights[i] = {-1, -1, -1}; // Invalidate the shorter/inner barrier
                }
            }
        }

        if(it->height > last_height) { // If we found a higher barrier
            last_height = it->height;
            last_idx = curr_idx;
        }
    }

    // Copy only the barriers we can change to a separate vector
    std::vector<barrier> changeable(k);

    auto c = std::copy_if(heights.begin(), heights.end(), changeable.begin(),
        [](const barrier& val) {
            return val.max_increase != -1;
        });

    // Resize to make sure there are no empty barriers in the end
    changeable.resize(std::distance(changeable.begin(), c));

    // Update k
    k = changeable.size();

    auto max_water = calculate_water(heights);
    auto min_k = 0;

    range(i, 1, k+1) {
        std::vector<barrier> temp = changeable;

        do
        {
            range(j, 0, i) {
                auto b = temp[j];
                heights[b.idx].height += b.max_increase;
            }

            auto curr_water = calculate_water(heights);
            if(curr_water > max_water) {
                max_water = curr_water;
                min_k = i;
            }

            range(j, 0, i) {
                auto b = temp[j];
                heights[b.idx].height = b.height;
            }
        } while(std::next_permutation(temp.begin(), temp.end()));
    }

    std::cout << min_k << " " << max_water << endl;

    return 0;
}
