#include <bits/stdc++.h>

#define endl '\n'

#define range(i, a, b) for(ll i = a; i <= b; ++i)

typedef unsigned long long ll;

class int_ratio
{
public:
    int_ratio(ll numerator, ll denominator);

    void simplify();

    ll get_numerator();
    ll get_denominator();

    bool operator== (const int_ratio& other)
    {
        return this->numerator_ == other.numerator_ &&
               this->denominator_ == other.denominator_;
    };

    bool operator!= (const int_ratio& other) {
        return !(*this == other);
    }
private:
    ll numerator_;
    ll denominator_;
};

int_ratio::int_ratio(ll numerator, ll denominator)
{
    this->numerator_ = numerator;
    this->denominator_ = denominator;

    if(this->numerator_ > this->denominator_) {
        std::swap(this->numerator_, this->denominator_);
    }
}

void int_ratio::simplify()
{
    if(this->denominator_ == 0) {
        return;
    }

    auto d = std::__gcd(this->numerator_, this->denominator_);

    this->numerator_ /= d;
    this->denominator_ /= d;
}

ll int_ratio::get_numerator()
{
    return this->numerator_;
}

ll int_ratio::get_denominator()
{
    return this->denominator_;
}

bool check_solution(ll a, ll b, ll x, ll y, int_ratio alpha)
{
    auto xy_ratio = int_ratio(x, y);
    xy_ratio.simplify();

    auto new_a = a - x;
    auto new_b = b - y;

    auto new_ratio = int_ratio(new_a, new_b);
    new_ratio.simplify();

    return xy_ratio != alpha &&
           ((new_a == new_b && new_b == 0) ||
             new_ratio == alpha);
}

int main()
{
    std::ios::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    ll a, b;
    std::cin >> a >> b;

    auto alpha = int_ratio(a, b);

    auto alpha_simplified = alpha;
    alpha_simplified.simplify();

    if(alpha == alpha_simplified) {
        std::cout << "0" << endl;
        return 0;
    }

    auto answer = 0ULL;
    range(x, 0, a) {
        range(y, 0, b) {
            if(x == y && y == 0) {
                continue;
            }

            if(check_solution(a, b, x, y, alpha_simplified)) {
                ++answer;
            }
        }
    }

    std::cout << answer << endl;

    return 0;
}
